# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/universe/universe.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.universe import space_pb2 as eolymp_dot_universe_dot_space__pb2
from eolymp.universe import permission_pb2 as eolymp_dot_universe_dot_permission__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/universe/universe.proto',
  package='eolymp.universe',
  syntax='proto3',
  serialized_options=b'Z7github.com/eolymp/contracts/go/eolymp/universe;universe',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65olymp/universe/universe.proto\x12\x0f\x65olymp.universe\x1a\x1d\x65olymp/annotations/http.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1b\x65olymp/universe/space.proto\x1a eolymp/universe/permission.proto\"9\n\x10\x43reateSpaceInput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"%\n\x11\x43reateSpaceOutput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"K\n\x10UpdateSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12%\n\x05space\x18\x02 \x01(\x0b\x32\x16.eolymp.universe.Space\"\x13\n\x11UpdateSpaceOutput\"$\n\x10\x44\x65leteSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"\x13\n\x11\x44\x65leteSpaceOutput\"\x1f\n\x10LookupSpaceInput\x12\x0b\n\x03key\x18\x01 \x01(\t\":\n\x11LookupSpaceOutput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"&\n\x12\x44\x65scribeSpaceInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"<\n\x13\x44\x65scribeSpaceOutput\x12%\n\x05space\x18\x01 \x01(\x0b\x32\x16.eolymp.universe.Space\"&\n\x12\x44\x65scribeQuotaInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"B\n\x13\x44\x65scribeQuotaOutput\x12+\n\x05quota\x18\x01 \x01(\x0b\x32\x1c.eolymp.universe.Space.Quota\"\xe0\x02\n\x0fListSpacesInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x38\n\x07\x66ilters\x18( \x01(\x0b\x32\'.eolymp.universe.ListSpacesInput.Filter\x1a\xf4\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12+\n\x03key\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x04name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12-\n\x03own\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06member\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\"H\n\x10ListSpacesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12%\n\x05items\x18\x02 \x03(\x0b\x32\x16.eolymp.universe.Space\"i\n\x14GrantPermissionInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12.\n\x04role\x18\x02 \x01(\x0e\x32 .eolymp.universe.Permission.Role\x12\x0f\n\x07user_id\x18\x03 \x01(\t\"\x17\n\x15GrantPermissionOutput\":\n\x15RevokePermissionInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\"\x18\n\x16RevokePermissionOutput\"<\n\x17\x44\x65scribePermissionInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"K\n\x18\x44\x65scribePermissionOutput\x12/\n\npermission\x18\x01 \x01(\x0b\x32\x1b.eolymp.universe.Permission\"-\n\x19IntrospectPermissionInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\"M\n\x1aIntrospectPermissionOutput\x12/\n\npermission\x18\x01 \x01(\x0b\x32\x1b.eolymp.universe.Permission\"\x9d\x02\n\x14ListPermissionsInput\x12\x10\n\x08space_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12=\n\x07\x66ilters\x18( \x01(\x0b\x32,.eolymp.universe.ListPermissionsInput.Filter\x1a\x95\x01\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12/\n\x07user_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04role\x18\x03 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"R\n\x15ListPermissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.eolymp.universe.Permission2\xf7\x10\n\x08Universe\x12\x9c\x01\n\x0b\x43reateSpace\x12!.eolymp.universe.CreateSpaceInput\x1a\".eolymp.universe.CreateSpaceOutput\"F\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x15\"\x10/universe/spacesb\x01*\x12\xa4\x01\n\x0bUpdateSpace\x12!.eolymp.universe.UpdateSpaceInput\x1a\".eolymp.universe.UpdateSpaceOutput\"N\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d\x1a\x1b/universe/spaces/{space_id}\x12\xa4\x01\n\x0b\x44\x65leteSpace\x12!.eolymp.universe.DeleteSpaceInput\x1a\".eolymp.universe.DeleteSpaceOutput\"N\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1d*\x1b/universe/spaces/{space_id}\x12\x90\x01\n\x0bLookupSpace\x12!.eolymp.universe.LookupSpaceInput\x1a\".eolymp.universe.LookupSpaceOutput\":\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02%\x12\x1c/universe/space-lookup/{key}b\x05space\x12\x95\x01\n\rDescribeSpace\x12#.eolymp.universe.DescribeSpaceInput\x1a$.eolymp.universe.DescribeSpaceOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02$\x12\x1b/universe/spaces/{space_id}b\x05space\x12\x9b\x01\n\rDescribeQuota\x12#.eolymp.universe.DescribeQuotaInput\x1a$.eolymp.universe.DescribeQuotaOutput\"?\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02*\x12!/universe/spaces/{space_id}/quotab\x05quota\x12\x98\x01\n\nListSpaces\x12 .eolymp.universe.ListSpacesInput\x1a!.eolymp.universe.ListSpacesOutput\"E\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x15\x12\x10/universe/spacesb\x01*\x12\xc9\x01\n\x0fGrantPermission\x12%.eolymp.universe.GrantPermissionInput\x1a&.eolymp.universe.GrantPermissionOutput\"g\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x36\x1a\x31/universe/spaces/{space_id}/permissions/{user_id}b\x01*\x12\xcc\x01\n\x10RevokePermission\x12&.eolymp.universe.RevokePermissionInput\x1a\'.eolymp.universe.RevokePermissionOutput\"g\x82\xe3\n\x18\x8a\xe3\n\x14universe:space:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x36*1/universe/spaces/{space_id}/permissions/{user_id}b\x01*\x12\xda\x01\n\x12\x44\x65scribePermission\x12(.eolymp.universe.DescribePermissionInput\x1a).eolymp.universe.DescribePermissionOutput\"o\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02?\x12\x31/universe/spaces/{space_id}/permissions/{user_id}b\npermission\x12\xe0\x01\n\x14IntrospectPermission\x12*.eolymp.universe.IntrospectPermissionInput\x1a+.eolymp.universe.IntrospectPermissionOutput\"o\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02?\x12\x31/universe/spaces/{space_id}/introspect-permissionb\npermission\x12\xbe\x01\n\x0fListPermissions\x12%.eolymp.universe.ListPermissionsInput\x1a&.eolymp.universe.ListPermissionsOutput\"\\\x82\xe3\n\x17\x8a\xe3\n\x13universe:space:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02,\x12\'/universe/spaces/{space_id}/permissionsb\x01*B9Z7github.com/eolymp/contracts/go/eolymp/universe;universeb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_universe_dot_space__pb2.DESCRIPTOR,eolymp_dot_universe_dot_permission__pb2.DESCRIPTOR,])




_CREATESPACEINPUT = _descriptor.Descriptor(
  name='CreateSpaceInput',
  full_name='eolymp.universe.CreateSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.CreateSpaceInput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=305,
)


_CREATESPACEOUTPUT = _descriptor.Descriptor(
  name='CreateSpaceOutput',
  full_name='eolymp.universe.CreateSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.CreateSpaceOutput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=344,
)


_UPDATESPACEINPUT = _descriptor.Descriptor(
  name='UpdateSpaceInput',
  full_name='eolymp.universe.UpdateSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.UpdateSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.UpdateSpaceInput.space', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=421,
)


_UPDATESPACEOUTPUT = _descriptor.Descriptor(
  name='UpdateSpaceOutput',
  full_name='eolymp.universe.UpdateSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=442,
)


_DELETESPACEINPUT = _descriptor.Descriptor(
  name='DeleteSpaceInput',
  full_name='eolymp.universe.DeleteSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.DeleteSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=480,
)


_DELETESPACEOUTPUT = _descriptor.Descriptor(
  name='DeleteSpaceOutput',
  full_name='eolymp.universe.DeleteSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=501,
)


_LOOKUPSPACEINPUT = _descriptor.Descriptor(
  name='LookupSpaceInput',
  full_name='eolymp.universe.LookupSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.universe.LookupSpaceInput.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=503,
  serialized_end=534,
)


_LOOKUPSPACEOUTPUT = _descriptor.Descriptor(
  name='LookupSpaceOutput',
  full_name='eolymp.universe.LookupSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.LookupSpaceOutput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=594,
)


_DESCRIBESPACEINPUT = _descriptor.Descriptor(
  name='DescribeSpaceInput',
  full_name='eolymp.universe.DescribeSpaceInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.DescribeSpaceInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=634,
)


_DESCRIBESPACEOUTPUT = _descriptor.Descriptor(
  name='DescribeSpaceOutput',
  full_name='eolymp.universe.DescribeSpaceOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space', full_name='eolymp.universe.DescribeSpaceOutput.space', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=696,
)


_DESCRIBEQUOTAINPUT = _descriptor.Descriptor(
  name='DescribeQuotaInput',
  full_name='eolymp.universe.DescribeQuotaInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.DescribeQuotaInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=698,
  serialized_end=736,
)


_DESCRIBEQUOTAOUTPUT = _descriptor.Descriptor(
  name='DescribeQuotaOutput',
  full_name='eolymp.universe.DescribeQuotaOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='quota', full_name='eolymp.universe.DescribeQuotaOutput.quota', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=804,
)


_LISTSPACESINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.universe.ListSpacesInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.universe.ListSpacesInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='eolymp.universe.ListSpacesInput.Filter.key', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='eolymp.universe.ListSpacesInput.Filter.name', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='own', full_name='eolymp.universe.ListSpacesInput.Filter.own', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member', full_name='eolymp.universe.ListSpacesInput.Filter.member', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=915,
  serialized_end=1159,
)

_LISTSPACESINPUT = _descriptor.Descriptor(
  name='ListSpacesInput',
  full_name='eolymp.universe.ListSpacesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.universe.ListSpacesInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.universe.ListSpacesInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.universe.ListSpacesInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSPACESINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=1159,
)


_LISTSPACESOUTPUT = _descriptor.Descriptor(
  name='ListSpacesOutput',
  full_name='eolymp.universe.ListSpacesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.universe.ListSpacesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.universe.ListSpacesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1233,
)


_GRANTPERMISSIONINPUT = _descriptor.Descriptor(
  name='GrantPermissionInput',
  full_name='eolymp.universe.GrantPermissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.GrantPermissionInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.GrantPermissionInput.role', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.GrantPermissionInput.user_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1235,
  serialized_end=1340,
)


_GRANTPERMISSIONOUTPUT = _descriptor.Descriptor(
  name='GrantPermissionOutput',
  full_name='eolymp.universe.GrantPermissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1365,
)


_REVOKEPERMISSIONINPUT = _descriptor.Descriptor(
  name='RevokePermissionInput',
  full_name='eolymp.universe.RevokePermissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.RevokePermissionInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.RevokePermissionInput.user_id', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1367,
  serialized_end=1425,
)


_REVOKEPERMISSIONOUTPUT = _descriptor.Descriptor(
  name='RevokePermissionOutput',
  full_name='eolymp.universe.RevokePermissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1451,
)


_DESCRIBEPERMISSIONINPUT = _descriptor.Descriptor(
  name='DescribePermissionInput',
  full_name='eolymp.universe.DescribePermissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.DescribePermissionInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.DescribePermissionInput.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1453,
  serialized_end=1513,
)


_DESCRIBEPERMISSIONOUTPUT = _descriptor.Descriptor(
  name='DescribePermissionOutput',
  full_name='eolymp.universe.DescribePermissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='eolymp.universe.DescribePermissionOutput.permission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1590,
)


_INTROSPECTPERMISSIONINPUT = _descriptor.Descriptor(
  name='IntrospectPermissionInput',
  full_name='eolymp.universe.IntrospectPermissionInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.IntrospectPermissionInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1592,
  serialized_end=1637,
)


_INTROSPECTPERMISSIONOUTPUT = _descriptor.Descriptor(
  name='IntrospectPermissionOutput',
  full_name='eolymp.universe.IntrospectPermissionOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='eolymp.universe.IntrospectPermissionOutput.permission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1639,
  serialized_end=1716,
)


_LISTPERMISSIONSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.universe.ListPermissionsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.universe.ListPermissionsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='eolymp.universe.ListPermissionsInput.Filter.user_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='eolymp.universe.ListPermissionsInput.Filter.role', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1855,
  serialized_end=2004,
)

_LISTPERMISSIONSINPUT = _descriptor.Descriptor(
  name='ListPermissionsInput',
  full_name='eolymp.universe.ListPermissionsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='space_id', full_name='eolymp.universe.ListPermissionsInput.space_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.universe.ListPermissionsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.universe.ListPermissionsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.universe.ListPermissionsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPERMISSIONSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=2004,
)


_LISTPERMISSIONSOUTPUT = _descriptor.Descriptor(
  name='ListPermissionsOutput',
  full_name='eolymp.universe.ListPermissionsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.universe.ListPermissionsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.universe.ListPermissionsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2006,
  serialized_end=2088,
)

_CREATESPACEINPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_UPDATESPACEINPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_LOOKUPSPACEOUTPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_DESCRIBESPACEOUTPUT.fields_by_name['space'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_DESCRIBEQUOTAOUTPUT.fields_by_name['quota'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE_QUOTA
_LISTSPACESINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSPACESINPUT_FILTER.fields_by_name['key'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSPACESINPUT_FILTER.fields_by_name['name'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONSTRING
_LISTSPACESINPUT_FILTER.fields_by_name['own'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTSPACESINPUT_FILTER.fields_by_name['member'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONBOOL
_LISTSPACESINPUT_FILTER.containing_type = _LISTSPACESINPUT
_LISTSPACESINPUT.fields_by_name['filters'].message_type = _LISTSPACESINPUT_FILTER
_LISTSPACESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_universe_dot_space__pb2._SPACE
_GRANTPERMISSIONINPUT.fields_by_name['role'].enum_type = eolymp_dot_universe_dot_permission__pb2._PERMISSION_ROLE
_DESCRIBEPERMISSIONOUTPUT.fields_by_name['permission'].message_type = eolymp_dot_universe_dot_permission__pb2._PERMISSION
_INTROSPECTPERMISSIONOUTPUT.fields_by_name['permission'].message_type = eolymp_dot_universe_dot_permission__pb2._PERMISSION
_LISTPERMISSIONSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTPERMISSIONSINPUT_FILTER.fields_by_name['user_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTPERMISSIONSINPUT_FILTER.fields_by_name['role'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONENUM
_LISTPERMISSIONSINPUT_FILTER.containing_type = _LISTPERMISSIONSINPUT
_LISTPERMISSIONSINPUT.fields_by_name['filters'].message_type = _LISTPERMISSIONSINPUT_FILTER
_LISTPERMISSIONSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_universe_dot_permission__pb2._PERMISSION
DESCRIPTOR.message_types_by_name['CreateSpaceInput'] = _CREATESPACEINPUT
DESCRIPTOR.message_types_by_name['CreateSpaceOutput'] = _CREATESPACEOUTPUT
DESCRIPTOR.message_types_by_name['UpdateSpaceInput'] = _UPDATESPACEINPUT
DESCRIPTOR.message_types_by_name['UpdateSpaceOutput'] = _UPDATESPACEOUTPUT
DESCRIPTOR.message_types_by_name['DeleteSpaceInput'] = _DELETESPACEINPUT
DESCRIPTOR.message_types_by_name['DeleteSpaceOutput'] = _DELETESPACEOUTPUT
DESCRIPTOR.message_types_by_name['LookupSpaceInput'] = _LOOKUPSPACEINPUT
DESCRIPTOR.message_types_by_name['LookupSpaceOutput'] = _LOOKUPSPACEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeSpaceInput'] = _DESCRIBESPACEINPUT
DESCRIPTOR.message_types_by_name['DescribeSpaceOutput'] = _DESCRIBESPACEOUTPUT
DESCRIPTOR.message_types_by_name['DescribeQuotaInput'] = _DESCRIBEQUOTAINPUT
DESCRIPTOR.message_types_by_name['DescribeQuotaOutput'] = _DESCRIBEQUOTAOUTPUT
DESCRIPTOR.message_types_by_name['ListSpacesInput'] = _LISTSPACESINPUT
DESCRIPTOR.message_types_by_name['ListSpacesOutput'] = _LISTSPACESOUTPUT
DESCRIPTOR.message_types_by_name['GrantPermissionInput'] = _GRANTPERMISSIONINPUT
DESCRIPTOR.message_types_by_name['GrantPermissionOutput'] = _GRANTPERMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['RevokePermissionInput'] = _REVOKEPERMISSIONINPUT
DESCRIPTOR.message_types_by_name['RevokePermissionOutput'] = _REVOKEPERMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['DescribePermissionInput'] = _DESCRIBEPERMISSIONINPUT
DESCRIPTOR.message_types_by_name['DescribePermissionOutput'] = _DESCRIBEPERMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['IntrospectPermissionInput'] = _INTROSPECTPERMISSIONINPUT
DESCRIPTOR.message_types_by_name['IntrospectPermissionOutput'] = _INTROSPECTPERMISSIONOUTPUT
DESCRIPTOR.message_types_by_name['ListPermissionsInput'] = _LISTPERMISSIONSINPUT
DESCRIPTOR.message_types_by_name['ListPermissionsOutput'] = _LISTPERMISSIONSOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSpaceInput = _reflection.GeneratedProtocolMessageType('CreateSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.CreateSpaceInput)
  })
_sym_db.RegisterMessage(CreateSpaceInput)

CreateSpaceOutput = _reflection.GeneratedProtocolMessageType('CreateSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.CreateSpaceOutput)
  })
_sym_db.RegisterMessage(CreateSpaceOutput)

UpdateSpaceInput = _reflection.GeneratedProtocolMessageType('UpdateSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateSpaceInput)
  })
_sym_db.RegisterMessage(UpdateSpaceInput)

UpdateSpaceOutput = _reflection.GeneratedProtocolMessageType('UpdateSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.UpdateSpaceOutput)
  })
_sym_db.RegisterMessage(UpdateSpaceOutput)

DeleteSpaceInput = _reflection.GeneratedProtocolMessageType('DeleteSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DeleteSpaceInput)
  })
_sym_db.RegisterMessage(DeleteSpaceInput)

DeleteSpaceOutput = _reflection.GeneratedProtocolMessageType('DeleteSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DeleteSpaceOutput)
  })
_sym_db.RegisterMessage(DeleteSpaceOutput)

LookupSpaceInput = _reflection.GeneratedProtocolMessageType('LookupSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.LookupSpaceInput)
  })
_sym_db.RegisterMessage(LookupSpaceInput)

LookupSpaceOutput = _reflection.GeneratedProtocolMessageType('LookupSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _LOOKUPSPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.LookupSpaceOutput)
  })
_sym_db.RegisterMessage(LookupSpaceOutput)

DescribeSpaceInput = _reflection.GeneratedProtocolMessageType('DescribeSpaceInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESPACEINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeSpaceInput)
  })
_sym_db.RegisterMessage(DescribeSpaceInput)

DescribeSpaceOutput = _reflection.GeneratedProtocolMessageType('DescribeSpaceOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESPACEOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeSpaceOutput)
  })
_sym_db.RegisterMessage(DescribeSpaceOutput)

DescribeQuotaInput = _reflection.GeneratedProtocolMessageType('DescribeQuotaInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEQUOTAINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeQuotaInput)
  })
_sym_db.RegisterMessage(DescribeQuotaInput)

DescribeQuotaOutput = _reflection.GeneratedProtocolMessageType('DescribeQuotaOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEQUOTAOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribeQuotaOutput)
  })
_sym_db.RegisterMessage(DescribeQuotaOutput)

ListSpacesInput = _reflection.GeneratedProtocolMessageType('ListSpacesInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSPACESINPUT_FILTER,
    '__module__' : 'eolymp.universe.universe_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSPACESINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesInput)
  })
_sym_db.RegisterMessage(ListSpacesInput)
_sym_db.RegisterMessage(ListSpacesInput.Filter)

ListSpacesOutput = _reflection.GeneratedProtocolMessageType('ListSpacesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSPACESOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListSpacesOutput)
  })
_sym_db.RegisterMessage(ListSpacesOutput)

GrantPermissionInput = _reflection.GeneratedProtocolMessageType('GrantPermissionInput', (_message.Message,), {
  'DESCRIPTOR' : _GRANTPERMISSIONINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.GrantPermissionInput)
  })
_sym_db.RegisterMessage(GrantPermissionInput)

GrantPermissionOutput = _reflection.GeneratedProtocolMessageType('GrantPermissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _GRANTPERMISSIONOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.GrantPermissionOutput)
  })
_sym_db.RegisterMessage(GrantPermissionOutput)

RevokePermissionInput = _reflection.GeneratedProtocolMessageType('RevokePermissionInput', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEPERMISSIONINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.RevokePermissionInput)
  })
_sym_db.RegisterMessage(RevokePermissionInput)

RevokePermissionOutput = _reflection.GeneratedProtocolMessageType('RevokePermissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEPERMISSIONOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.RevokePermissionOutput)
  })
_sym_db.RegisterMessage(RevokePermissionOutput)

DescribePermissionInput = _reflection.GeneratedProtocolMessageType('DescribePermissionInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPERMISSIONINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribePermissionInput)
  })
_sym_db.RegisterMessage(DescribePermissionInput)

DescribePermissionOutput = _reflection.GeneratedProtocolMessageType('DescribePermissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBEPERMISSIONOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.DescribePermissionOutput)
  })
_sym_db.RegisterMessage(DescribePermissionOutput)

IntrospectPermissionInput = _reflection.GeneratedProtocolMessageType('IntrospectPermissionInput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTPERMISSIONINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.IntrospectPermissionInput)
  })
_sym_db.RegisterMessage(IntrospectPermissionInput)

IntrospectPermissionOutput = _reflection.GeneratedProtocolMessageType('IntrospectPermissionOutput', (_message.Message,), {
  'DESCRIPTOR' : _INTROSPECTPERMISSIONOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.IntrospectPermissionOutput)
  })
_sym_db.RegisterMessage(IntrospectPermissionOutput)

ListPermissionsInput = _reflection.GeneratedProtocolMessageType('ListPermissionsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTPERMISSIONSINPUT_FILTER,
    '__module__' : 'eolymp.universe.universe_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.universe.ListPermissionsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTPERMISSIONSINPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListPermissionsInput)
  })
_sym_db.RegisterMessage(ListPermissionsInput)
_sym_db.RegisterMessage(ListPermissionsInput.Filter)

ListPermissionsOutput = _reflection.GeneratedProtocolMessageType('ListPermissionsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTPERMISSIONSOUTPUT,
  '__module__' : 'eolymp.universe.universe_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.universe.ListPermissionsOutput)
  })
_sym_db.RegisterMessage(ListPermissionsOutput)


DESCRIPTOR._options = None

_UNIVERSE = _descriptor.ServiceDescriptor(
  name='Universe',
  full_name='eolymp.universe.Universe',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2091,
  serialized_end=4258,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSpace',
    full_name='eolymp.universe.Universe.CreateSpace',
    index=0,
    containing_service=None,
    input_type=_CREATESPACEINPUT,
    output_type=_CREATESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\025\"\020/universe/spacesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSpace',
    full_name='eolymp.universe.Universe.UpdateSpace',
    index=1,
    containing_service=None,
    input_type=_UPDATESPACEINPUT,
    output_type=_UPDATESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035\032\033/universe/spaces/{space_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSpace',
    full_name='eolymp.universe.Universe.DeleteSpace',
    index=2,
    containing_service=None,
    input_type=_DELETESPACEINPUT,
    output_type=_DELETESPACEOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\035*\033/universe/spaces/{space_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LookupSpace',
    full_name='eolymp.universe.Universe.LookupSpace',
    index=3,
    containing_service=None,
    input_type=_LOOKUPSPACEINPUT,
    output_type=_LOOKUPSPACEOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002%\022\034/universe/space-lookup/{key}b\005space',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeSpace',
    full_name='eolymp.universe.Universe.DescribeSpace',
    index=4,
    containing_service=None,
    input_type=_DESCRIBESPACEINPUT,
    output_type=_DESCRIBESPACEOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002$\022\033/universe/spaces/{space_id}b\005space',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeQuota',
    full_name='eolymp.universe.Universe.DescribeQuota',
    index=5,
    containing_service=None,
    input_type=_DESCRIBEQUOTAINPUT,
    output_type=_DESCRIBEQUOTAOUTPUT,
    serialized_options=b'\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002*\022!/universe/spaces/{space_id}/quotab\005quota',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSpaces',
    full_name='eolymp.universe.Universe.ListSpaces',
    index=6,
    containing_service=None,
    input_type=_LISTSPACESINPUT,
    output_type=_LISTSPACESOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\025\022\020/universe/spacesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GrantPermission',
    full_name='eolymp.universe.Universe.GrantPermission',
    index=7,
    containing_service=None,
    input_type=_GRANTPERMISSIONINPUT,
    output_type=_GRANTPERMISSIONOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0026\0321/universe/spaces/{space_id}/permissions/{user_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RevokePermission',
    full_name='eolymp.universe.Universe.RevokePermission',
    index=8,
    containing_service=None,
    input_type=_REVOKEPERMISSIONINPUT,
    output_type=_REVOKEPERMISSIONOUTPUT,
    serialized_options=b'\202\343\n\030\212\343\n\024universe:space:write\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0026*1/universe/spaces/{space_id}/permissions/{user_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribePermission',
    full_name='eolymp.universe.Universe.DescribePermission',
    index=9,
    containing_service=None,
    input_type=_DESCRIBEPERMISSIONINPUT,
    output_type=_DESCRIBEPERMISSIONOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002?\0221/universe/spaces/{space_id}/permissions/{user_id}b\npermission',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IntrospectPermission',
    full_name='eolymp.universe.Universe.IntrospectPermission',
    index=10,
    containing_service=None,
    input_type=_INTROSPECTPERMISSIONINPUT,
    output_type=_INTROSPECTPERMISSIONOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002?\0221/universe/spaces/{space_id}/introspect-permissionb\npermission',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPermissions',
    full_name='eolymp.universe.Universe.ListPermissions',
    index=11,
    containing_service=None,
    input_type=_LISTPERMISSIONSINPUT,
    output_type=_LISTPERMISSIONSOUTPUT,
    serialized_options=b'\202\343\n\027\212\343\n\023universe:space:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002,\022\'/universe/spaces/{space_id}/permissionsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_UNIVERSE)

DESCRIPTOR.services_by_name['Universe'] = _UNIVERSE

# @@protoc_insertion_point(module_scope)
